[glib: 1/2] goption: Clarify G_OPTION_ARG_FILENAME documentation



commit e1992a0e0eaa183c5ce61d96a88fccac3cf40044
Author: Philip Withnall <withnall endlessm com>
Date:   Mon Jun 3 09:58:37 2019 +0100

    goption: Clarify G_OPTION_ARG_FILENAME documentation
    
    It’s already documented elsewhere, but not particularly obviously.
    Clarify argument encodings in the GOptionArg documentation.
    
    As reported on StackOverflow:
    https://stackoverflow.com/q/56416098/2931197.
    
    Signed-off-by: Philip Withnall <withnall endlessm com>

 glib/goption.h | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
---
diff --git a/glib/goption.h b/glib/goption.h
index 83d4f77fd..63552fb0d 100644
--- a/glib/goption.h
+++ b/glib/goption.h
@@ -93,11 +93,12 @@ typedef enum
 /**
  * GOptionArg:
  * @G_OPTION_ARG_NONE: No extra argument. This is useful for simple flags.
  * @G_OPTION_ARG_STRING: The option takes a string argument.
  * @G_OPTION_ARG_INT: The option takes an integer argument.
  * @G_OPTION_ARG_CALLBACK: The option provides a callback (of type
  *     #GOptionArgFunc) to parse the extra argument.
- * @G_OPTION_ARG_FILENAME: The option takes a filename as argument.
+ * @G_OPTION_ARG_FILENAME: The option takes a filename as argument, which will
+       be in the GLib filename encoding rather than UTF-8.
  * @G_OPTION_ARG_STRING_ARRAY: The option takes a string argument, multiple
  *     uses of the option are collected into an array of strings.
  * @G_OPTION_ARG_FILENAME_ARRAY: The option takes a filename as argument, 
@@ -93,11 +93,12 @@ typedef enum
  * GOptionArg:
  * @G_OPTION_ARG_NONE: No extra argument. This is useful for simple flags.
- * @G_OPTION_ARG_STRING: The option takes a string argument.
+ * @G_OPTION_ARG_STRING: The option takes a UTF-8 string argument.
  * @G_OPTION_ARG_INT: The option takes an integer argument.
  * @G_OPTION_ARG_CALLBACK: The option provides a callback (of type


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]